==> jammo_0.1.9.tar.gz: jammo-0.1.9/src/gui_clutter/json_helper.c <==
/**json_helper.c is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui and it parses json config files.
*/

//This is because of getline
#define _GNU_SOURCE

#include <string.h>
#include <stdlib.h>
#include <glib-object.h>

#include "../chum/chum.h" //THEMES_DIR
/*
This function generate config.json which config.c can read.
This reads from jammo/behaviours.json and /jammo/themes/$/objects.json

objects.json isn't valid json, it hasn't parenthesis
and each object is separated with empty rows.


problems: 
if there aren't any objects in theme.
if object doesn't have text 'behaviour-object-'
*/
void generate_json_for_theme(const gchar *theme_folder) {

  int bytes_read;
  size_t nbytes = 100;
  char *my_string;
  my_string = (char *) malloc (nbytes + 1);
  int cont=1; /*this used for while-loops*/


  //Output File//
  FILE *ofp;
  gchar* dir = THEMES_DIR;

  gchar *outputFilename = g_strdup_printf("%s/%s/config.json", dir, theme_folder);
  ofp = fopen(outputFilename, "w");

  if (ofp == NULL) {
      fprintf(stderr, "Can't open output file %s!\n",outputFilename);
      exit(1);
  }
  /////////////

  fprintf(ofp, "[\n");  //json starts with this


  //Behaviours file: just copy it beginning of output file
  FILE *ifp_behaviours;
  ifp_behaviours = fopen("../share/jammo/behaviours.json", "r");
  if (ifp_behaviours == NULL) {
      fprintf(stderr, "Can't open input file \n");
      exit(1);
  }

  cont=1;
  while (cont){
    bytes_read = getline (&my_string, &nbytes, ifp_behaviours);
    if (bytes_read <= 0) {
       cont=0;
    } else {
      fprintf(ofp, "%s",my_string);
    }
  }
//////////////////////////////////////////


  //make header for first object (suppose that there are at least one object)
  int object_counter=1;
  fprintf(ofp, "\n\n{\n");
  fprintf(ofp, "  \"id\" : \"object-%d\",\n",object_counter);
  fprintf(ofp, "  \"type\" : \"JammoTexture\",\n");
  object_counter++;

  //Read objects.json
  FILE *ifp;
  gchar *objects_filename = g_strdup_printf("%s/%s/objects.json", dir, theme_folder);

  ifp = fopen(objects_filename, "r");
  if (ifp == NULL) {
      fprintf(stderr, "Can't open input file '%s'\n",objects_filename);
      exit(1);
  }

  cont=1;
  char behaviour_type[100];
  while (cont){
    bytes_read = getline (&my_string, &nbytes, ifp);
    if (bytes_read <= 0) {
	  cont=0;
	  continue;
    } 

    //if this is row which defines behaviour type, let take it 
    char *pch=NULL;
    pch = strstr (my_string,"behaviour-object-");
    if (pch!=NULL){ 
	strncpy(behaviour_type,pch,strlen(pch)-4);
	behaviour_type[strlen(pch)-4]='\0';
	//printf("word is '%s'\n",behaviour_type);
    }

    //if this is empty row, we know this object is ready
    if (strcmp(my_string,"\n")==0) {
	//add footers to it
	fprintf(ofp, "  \"signals\": [\n");
	fprintf(ofp, "      {\n");
	fprintf(ofp, "        \"name\": \"show\",\n");
	fprintf(ofp, "        \"handler\": \"stage_start_behaviour\",\n");
	fprintf(ofp, "        \"object\":  \"%s\",\n",behaviour_type);
	fprintf(ofp, "      }\n");
	fprintf(ofp, "    ]\n");

	//and add headers of the next object
	fprintf(ofp, "},\n\n");
	fprintf(ofp, "{\n");
	fprintf(ofp, "  \"id\" : \"object-%d\",\n",object_counter);
	fprintf(ofp, "  \"type\" : \"JammoTexture\",");
	object_counter++;
    }

    //write reader row to output file.
    fprintf(ofp, "%s",my_string);
  }

//and footers for last object
  fprintf(ofp, "  \"signals\": [\n");
  fprintf(ofp, "      {\n");
  fprintf(ofp, "        \"name\": \"show\",\n");
  fprintf(ofp, "        \"handler\": \"stage_start_behaviour\",\n");
  fprintf(ofp, "        \"object\":  \"%s\",\n",behaviour_type);
  fprintf(ofp, "      }\n");
  fprintf(ofp, "    ]\n");

//this is the end of json-files
  fprintf(ofp, "},\n\n\n]\n");


fclose(ifp);
fclose(ifp_behaviours);
fclose(ofp);
}

==> jammo_0.1.13.tar.gz: jammo-0.1.13/src/gui_clutter/json_helper.c <==
/**json_helper.c is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui and it parses json config files.
*/

//This is because of getline
#define _GNU_SOURCE

#include <string.h>
#include <stdlib.h>
#include <glib-object.h>

#include "../chum/chum.h" //THEMES_DIR
/*
This function generate config.json which config.c can read.
This reads from jammo/behaviours.json and /jammo/themes/$/objects.json

objects.json isn't valid json, it hasn't parenthesis
and each object is separated with empty rows.


problems: 
if there aren't any objects in theme.
if object doesn't have text 'behaviour-object-'
*/
void generate_json_for_theme(const gchar *theme_folder) {

  int bytes_read;
  size_t nbytes = 100;
  char *my_string;
  my_string = (char *) malloc (nbytes + 1);
  int cont=1; /*this used for while-loops*/


  //Output File//
  FILE *ofp;
  gchar* dir = THEMES_DIR;

  gchar *outputFilename = g_strdup_printf("%s/%s/config.json", dir, theme_folder);
  ofp = fopen(outputFilename, "w");

  if (ofp == NULL) {
      fprintf(stderr, "Can't open output file %s!\n",outputFilename);
      exit(1);
  }
  /////////////

  fprintf(ofp, "[\n");  //json starts with this


  //Behaviours file: just copy it beginning of output file
  FILE *ifp_behaviours;
  ifp_behaviours = fopen(g_strdup_printf("%s/behaviours.json",DATA_DIR), "r");
  if (ifp_behaviours == NULL) {
      fprintf(stderr, "Can't open input file \n");
      exit(1);
  }

  cont=1;
  while (cont){
    bytes_read = getline (&my_string, &nbytes, ifp_behaviours);
    if (bytes_read <= 0) {
       cont=0;
    } else {
      fprintf(ofp, "%s",my_string);
    }
  }
//////////////////////////////////////////


  //make header for first object (suppose that there are at least one object)
  int object_counter=1;
  fprintf(ofp, "\n\n{\n");
  fprintf(ofp, "  \"id\" : \"object-%d\",\n",object_counter);
  fprintf(ofp, "  \"type\" : \"JammoTexture\",\n");
  object_counter++;

  //Read objects.json
  FILE *ifp;
  gchar *objects_filename = g_strdup_printf("%s/%s/objects.json", dir, theme_folder);

  ifp = fopen(objects_filename, "r");
  if (ifp == NULL) {
      fprintf(stderr, "Can't open input file '%s'\n",objects_filename);
      exit(1);
  }

  cont=1;
  char behaviour_type[100];
  while (cont){
    bytes_read = getline (&my_string, &nbytes, ifp);
    if (bytes_read <= 0) {
	  cont=0;
	  continue;
    } 

    //if this is row which defines behaviour type, let take it 
    char *pch=NULL;
    pch = strstr (my_string,"behaviour-object-");
    if (pch!=NULL){ 
	strncpy(behaviour_type,pch,strlen(pch)-4);
	behaviour_type[strlen(pch)-4]='\0';
	//printf("word is '%s'\n",behaviour_type);
    }

    //if this is empty row, we know this object is ready
    if (strcmp(my_string,"\n")==0) {
	//add footers to it
	fprintf(ofp, "  \"signals\": [\n");
	fprintf(ofp, "      {\n");
	fprintf(ofp, "        \"name\": \"show\",\n");
	fprintf(ofp, "        \"handler\": \"stage_start_behaviour\",\n");
	fprintf(ofp, "        \"object\":  \"%s\",\n",behaviour_type);
	fprintf(ofp, "      }\n");
	fprintf(ofp, "    ]\n");

	//and add headers of the next object
	fprintf(ofp, "},\n\n");
	fprintf(ofp, "{\n");
	fprintf(ofp, "  \"id\" : \"object-%d\",\n",object_counter);
	fprintf(ofp, "  \"type\" : \"JammoTexture\",");
	object_counter++;
    }

    //write reader row to output file.
    fprintf(ofp, "%s",my_string);
  }

//and footers for last object
  fprintf(ofp, "  \"signals\": [\n");
  fprintf(ofp, "      {\n");
  fprintf(ofp, "        \"name\": \"show\",\n");
  fprintf(ofp, "        \"handler\": \"stage_start_behaviour\",\n");
  fprintf(ofp, "        \"object\":  \"%s\",\n",behaviour_type);
  fprintf(ofp, "      }\n");
  fprintf(ofp, "    ]\n");

//this is the end of json-files
  fprintf(ofp, "},\n\n\n]\n");


fclose(ifp);
fclose(ifp_behaviours);
fclose(ofp);
}
